# 2021-06-24 - Stable Pool

Deployment of the `StablePoolFactory`, for Stable Pools of up to 5 tokens.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`StablePool` ABI](./abi/StablePool.json)
